@@ -9,7 +9,7 @@
 
 #include <QObject>
 
-using namespace KIdentityManagement;
+using namespace KIdentityManagementCore;
 
 class IdendentitiesCache : public QObject
 {
@@ -23,7 +23,7 @@ public:
         slotIdentitiesChanged();
     }
 
-    Q_REQUIRED_RESULT const QSet<QString> &emails() const
+    [[nodiscard]] const QSet<QString> &emails() const
     {
         return mEmails;
     }
@@ -45,12 +45,12 @@ private:
 
 Q_GLOBAL_STATIC(IdendentitiesCache, sIdentitiesCache)
 
-bool KIdentityManagement::thatIsMe(const QString &email)
+bool KIdentityManagementCore::thatIsMe(const QString &email)
 {
     return allEmails().contains(email.toLower());
 }
 
-const QSet<QString> &KIdentityManagement::allEmails()
+const QSet<QString> &KIdentityManagementCore::allEmails()
 {
     return sIdentitiesCache()->emails();
 }
